@@ -47,6 +47,7 @@ class AnyUrlWidget(widgets.MultiWidget):
 
     class Media:
         js = ('any_urlfield/any_urlfield.js',)
+        css = {'all': ('any_urlfield/any_urlfield.css',)}
 
 
     def __init__(self, url_type_registry, attrs=None):
@@ -102,6 +103,12 @@ class AnyUrlWidget(widgets.MultiWidget):
         return result
 
 
+    def _has_changed(self, initial, data):
+        if initial is None:
+            initial = [u'http', u'', u'', u'']
+        return super(AnyUrlWidget, self)._has_changed(initial, data)
+
+
     def format_output(self, rendered_widgets):
         """
         Custom rendering of the widgets.
